@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
+'''Mount your JottaCloud files locally and use it with your normal file tools'''
 #
 # This file is part of jottafs.
 #
@@ -24,7 +25,7 @@ __author__ = 'havard@gulldahl.no'
 
 # importing stdlib
 import sys, os, pwd, stat, errno, netrc
-import urllib, logging, datetime
+import urllib, logging, datetime, argparse
 import time
 import itertools
 try:
@@ -34,7 +35,7 @@ except ImportError:
 
 
 # import jotta
-from jottalib import JFS
+from jottalib import JFS, __version__
 
 # import dependenceis (get them with pip!)
 try:
@@ -305,9 +306,26 @@ class JottaFuse(LoggingMixIn, Operations):
 
 
 if __name__ == '__main__':
-    if len(sys.argv) != 2:
-        print('usage: %s <mountpoint>' % sys.argv[0])
-        sys.exit(1)
+    def is_dir(path):
+        if not os.path.isdir(path):
+            raise argparse.ArgumentTypeError('%s is not a valid directory' % path)
+        return path
+    parser = argparse.ArgumentParser(description=__doc__,
+                                     epilog="""The program expects to find an entry for "jottacloud" in your .netrc,
+                                     or JOTTACLOUD_USERNAME and JOTTACLOUD_PASSWORD in the running environment.
+                                     This is not an official JottaCloud project.""")
+    parser.add_argument('--debug', action='store_true', help='Add a lot of messages to help debug')
+    parser.add_argument('--debug-http', action='store_true', help='Show all HTTP traffic')
+    parser.add_argument('--version', action='version', version=__version__)
+    parser.add_argument('mountpoint', type=is_dir, help='A path to an existing directory where you want your JottaCloud tree mounted')
+    args = parser.parse_args()
+    if args.debug_http:
+        import httplib
+        httplib.HTTPConnection.debuglevel = 1
+    if args.debug:
+        requests_log = logging.getLogger("requests.packages.urllib3")
+        requests_log.setLevel(logging.DEBUG)
+        requests_log.propagate = True
 
     try:
         n = netrc.netrc()
@@ -316,6 +334,6 @@ if __name__ == '__main__':
         username = os.environ['JOTTACLOUD_USERNAME']
         password = os.environ['JOTTACLOUD_PASSWORD']
 
-    fuse = FUSE(JottaFuse(username, password), sys.argv[1], foreground=True, nothreads=False)
+    fuse = FUSE(JottaFuse(username, password), args.mountpoint, foreground=True, nothreads=args.debug)
 
 
